@@ -368,7 +368,20 @@ def init_conditions(x, r, p, blocks, opt_nan, Rcon, q, nQ, i_idio, clock='m', te
                                         # Store loadings (only up to available columns in C_block)
                                         n_loadings = min(pC_freq * r_i, C_block.shape[1])
                                         if n_loadings > 0:
-                                            C_block[j, :n_loadings] = loadings[:n_loadings]
+                                            # Clip initial loadings to prevent extreme values
+                                            # This helps prevent Q explosion during C normalization
+                                            max_loading_norm = safe_get_attr(config, "max_loading_norm", 10.0) if config is not None else 10.0
+                                            # Clip loadings: if norm is too large, scale down
+                                            loadings_to_store = loadings[:n_loadings]
+                                            if loadings_to_store.ndim == 1:
+                                                # Vector case: clip by norm
+                                                loading_norm = np.linalg.norm(loadings_to_store)
+                                                if loading_norm > max_loading_norm:
+                                                    loadings_to_store = loadings_to_store * (max_loading_norm / loading_norm)
+                                            else:
+                                                # Multi-dimensional: clip each element
+                                                loadings_to_store = np.clip(loadings_to_store, -max_loading_norm, max_loading_norm)
+                                            C_block[j, :n_loadings] = loadings_to_store
                                     except Exception:
                                         # If constrained LS fails, use unconstrained (fallback)
                                         try:
@@ -377,7 +390,19 @@ def init_conditions(x, r, p, blocks, opt_nan, Rcon, q, nQ, i_idio, clock='m', te
                                             loadings = gram_inv @ factor_projection_clean.T @ series_data_clean
                                             n_loadings = min(pC_freq * r_i, C_block.shape[1])
                                             if n_loadings > 0:
-                                                C_block[j, :n_loadings] = loadings[:n_loadings]
+                                                # Clip initial loadings to prevent extreme values
+                                                max_loading_norm = safe_get_attr(config, "max_loading_norm", 10.0) if config is not None else 10.0
+                                                # Clip loadings: if norm is too large, scale down
+                                                loadings_to_store = loadings[:n_loadings]
+                                                if loadings_to_store.ndim == 1:
+                                                    # Vector case: clip by norm
+                                                    loading_norm = np.linalg.norm(loadings_to_store)
+                                                    if loading_norm > max_loading_norm:
+                                                        loadings_to_store = loadings_to_store * (max_loading_norm / loading_norm)
+                                                else:
+                                                    # Multi-dimensional: clip each element
+                                                    loadings_to_store = np.clip(loadings_to_store, -max_loading_norm, max_loading_norm)
+                                                C_block[j, :n_loadings] = loadings_to_store
                                         except Exception:
                                             pass  # Leave as zeros
                         except Exception:
@@ -784,8 +809,8 @@ def em_step(params: EMStepParams) -> Tuple[np.ndarray, np.ndarray, np.ndarray, n
                     lambda_ridge = (trace_val / size_val) * 1e-5  # Scale factor
                     EZZ_lag_sub = EZZ_lag_sub + lambda_ridge * np.eye(size_val)
                     # Recompute condition number after regularization
-                    eigenvals = np.linalg.eigvals(EZZ_lag_sub)
-                    cond_num = (np.max(eigenvals) / max(np.min(eigenvals), 1e-12)) if np.max(eigenvals) > 0 else 1.0
+                eigenvals = np.linalg.eigvals(EZZ_lag_sub)
+                cond_num = (np.max(eigenvals) / max(np.min(eigenvals), 1e-12)) if np.max(eigenvals) > 0 else 1.0
                 EZZ_lag_inv = pinv(EZZ_lag_sub, rcond=1e-8) if cond_num > 1e12 else inv(EZZ_lag_sub)
             except _NUMERICAL_EXCEPTIONS:
                 EZZ_lag_inv = pinv(EZZ_lag_sub)
@@ -1180,6 +1205,12 @@ def em_step(params: EMStepParams) -> Tuple[np.ndarray, np.ndarray, np.ndarray, n
     # Hard floor: enforce min diagonal on R (≥ 1e-8)
     idio_min_var = getattr(config, 'idio_min_var', 1e-8) if config is not None else 1e-8
     R_diag = np.maximum(R_diag, idio_min_var)
+    
+    # R cap to prevent explosion: maximum allowed observation error variance
+    # For standardized data, R should typically be < 10
+    R_cap = safe_get_attr(config, "max_observation_variance", 10.0) if config is not None else 10.0
+    R_diag = np.minimum(R_diag, R_cap)
+    
     R_new = np.diag(R_diag)
     
     # Final stability operations
@@ -1212,22 +1243,61 @@ def em_step(params: EMStepParams) -> Tuple[np.ndarray, np.ndarray, np.ndarray, n
     has_slower_freq = (frequencies is not None and 
                       any(freq != clock for freq in frequencies if freq is not None))
     num_clock_factors = int(np.sum(r))  # Only clock-frequency factors (ppC=1 part)
-    if num_clock_factors > 0 and not has_slower_freq:
-        # Only normalize if there are no slower-frequency series
-        # (to avoid violating tent weight constraints)
-        for j in range(num_clock_factors):
-            norm = np.linalg.norm(C_new[:, j])
-            if norm > 1e-8:
-                # Normalize C column
-                C_new[:, j] = C_new[:, j] / norm
-                # Adjust Q to preserve variance
-                # Diagonal: Q[j,j] *= norm^2
-                Q_new[j, j] = Q_new[j, j] * (norm ** 2)
-                # Off-diagonal: Q[j,k] and Q[k,j] *= norm (for k != j)
-                for k in range(Q_new.shape[0]):
-                    if k != j:
-                        Q_new[j, k] = Q_new[j, k] * norm
-                        Q_new[k, j] = Q_new[k, j] * norm
+    
+    # Q cap to prevent explosion: maximum allowed innovation variance for factors
+    Q_cap_factor = safe_get_attr(config, "max_innovation_variance", 1.0) if config is not None else 1.0
+    
+    # Normalize C for clock-frequency factors to prevent scale issues
+    # Only normalize if C norm is in reasonable range (not too small, not too large)
+    # This prevents Q from becoming too small (when C norm is small) or too large (when C norm is large)
+    if num_clock_factors > 0:
+        # Check if there are slower-frequency series (tent weight constraints)
+        has_slower_freq = (frequencies is not None and 
+                          any(freq != clock for freq in frequencies if freq is not None))
+        
+        # Only normalize if no slower-frequency series (to avoid violating tent weight constraints)
+        if not has_slower_freq:
+            for j in range(num_clock_factors):
+                norm = np.linalg.norm(C_new[:, j])
+                if norm > 1e-8:
+                    # Only normalize if norm is in reasonable range
+                    # Too small norm (< 0.1) would make Q too small
+                    # Too large norm (> 10) would make Q too large
+                    C_norm_min = 0.1  # Minimum norm to normalize
+                    C_norm_cap = safe_get_attr(config, "max_loading_norm", 10.0) if config is not None else 10.0
+                    
+                    if C_norm_min <= norm <= C_norm_cap:
+                        # Normalize C column
+                        C_new[:, j] = C_new[:, j] / norm
+                        
+                        # Adjust Q to preserve variance: Q[j,j] *= norm^2
+                        Q_adjustment = norm ** 2
+                        Q_new[j, j] = Q_new[j, j] * Q_adjustment
+                        
+                        # Off-diagonal: Q[j,k] and Q[k,j] *= norm (for k != j)
+                        for k in range(Q_new.shape[0]):
+                            if k != j:
+                                Q_new[j, k] = Q_new[j, k] * norm
+                                Q_new[k, j] = Q_new[k, j] * norm
+                    # If norm is too small or too large, skip normalization to preserve stability
+        
+        # Re-apply Q floor and cap after C normalization to prevent extreme values
+        # C normalization can make Q very large (if C norm was large) or very small (if C norm was small)
+        Q_diag_after_norm = np.diag(Q_new).copy()
+        if num_factors > 0:
+            # Apply both floor and cap to factors after normalization
+            Q_diag_after_norm[:num_factors] = np.clip(
+                Q_diag_after_norm[:num_factors],
+                Q_min_factor,  # Floor: 0.01
+                Q_cap_factor   # Cap: 1.0 (configurable)
+            )
+            # Preserve idio components (only floor, no cap needed)
+            if num_factors < len(Q_diag_after_norm):
+                Q_diag_after_norm[num_factors:] = np.maximum(Q_diag_after_norm[num_factors:], idio_min_var)
+        else:
+            Q_diag_after_norm = np.maximum(Q_diag_after_norm, idio_min_var)
+        # Update Q with re-applied floor and cap
+        Q_new = np.diag(Q_diag_after_norm) + (Q_new - np.diag(np.diag(Q_new)))  # Preserve off-diagonal
     
     # Spectral radius cap on A (< 0.99) with minimal shrinkage
     eigenvals_A = np.linalg.eigvals(A_new)
